var structkv_config =
[
    [ "Bucket", "structkv_config.html#a11b636da727c17566d5ab1274f69fee5", null ],
    [ "Description", "structkv_config.html#a941e9cad2bab67f093bf4d9567b4749a", null ],
    [ "MaxValueSize", "structkv_config.html#a281156a9df0130abad7f3b2728ac35a5", null ],
    [ "History", "structkv_config.html#a0ec6b3afbfdaa33436e2ae748e986e98", null ],
    [ "TTL", "structkv_config.html#ad2f5503e2f2522cb52e0ba1b86983dba", null ],
    [ "MaxBytes", "structkv_config.html#a1bc37777aa91b8b57a70e7647670cd12", null ],
    [ "StorageType", "structkv_config.html#ad5db9a58224d93ab86b4cfc4c46f1897", null ],
    [ "Replicas", "structkv_config.html#a48f0f70383eff868321f9c94ae1a87cd", null ],
    [ "RePublish", "structkv_config.html#ae172d3e442eef1a57cd7cf266d9e8951", null ]
];